# Generated by asset_id_files.py

AERIAL_TRAINING_SITE_MREA = 0x40F7447E
AERIE_MREA = 0x5D3A0001
AERIE_ACCESS_MREA = 0xDF073157
AERIE_TRANSPORT_STATION_MREA = 0xBAF94A13
AGON_TRANSPORT_ACCESS_MREA = 0x750BBFEF
CENTRAL_AREA_TRANSPORT_EAST_MREA = 0x1152015D
CENTRAL_AREA_TRANSPORT_WEST_MREA = 0x70E48580
CENTRAL_HIVE_EAST_TRANSPORT_MREA = 0xC2D7966B
CENTRAL_HIVE_WEST_TRANSPORT_MREA = 0x6CBCD4AB
CHECKPOINT_STATION_MREA = 0x844A690C
CONTROLLER_ACCESS_MREA = 0xE89BDC92
CULLING_CHAMBER_MREA = 0x690B786A
DYNAMO_ACCESS_MREA = 0x42C85AD9
DYNAMO_STORAGE_MREA = 0x1F7728F8
DYNAMO_WORKS_MREA = 0xC0113CE8
ENTRANCE_DEFENSE_HALL_MREA = 0xA70EA82B
GRAND_ABYSS_MREA = 0x237EDE04
HALL_OF_COMBAT_MASTERY_MREA = 0x5571E89E
HAZING_CLIFF_MREA = 0x37814F2A
HIVE_AMMO_STATION_MREA = 0xF1DF78DC
HIVE_CACHE_1_MREA = 0x5F43767D
HIVE_CACHE_3_MREA = 0x072FCFBC
HIVE_CONTROLLER_ACCESS_MREA = 0x26AC7F1E
HIVE_DYNAMO_ACCESS_MREA = 0xFBAF3B2B
HIVE_DYNAMO_WORKS_MREA = 0xF24EF6B4
HIVE_ENERGY_CONTROLLER_MREA = 0x2DECC318
HIVE_ENTRANCE_MREA = 0xF3FA4121
HIVE_GYRO_ACCESS_MREA = 0x2735236B
HIVE_GYRO_CHAMBER_MREA = 0xA3656292
HIVE_PORTAL_CHAMBER_MREA = 0x7B94B06B
HIVE_REACTOR_MREA = 0xF8DBC03D
HIVE_REACTOR_ACCESS_MREA = 0xB026CCEB
HIVE_SAVE_STATION_1_MREA = 0xBB57222F
HIVE_SAVE_STATION_2_MREA = 0x22B5442E
HIVE_SUMMIT_MREA = 0x9D804955
HIVE_TEMPLE_MREA = 0xA92F00B3
HIVE_TEMPLE_ACCESS_MREA = 0xEC875FEB
JUDGMENT_DROP_MREA = 0x55C479EB
MAIN_ENERGY_CONTROLLER_MREA = 0x57134DC2
MAIN_GYRO_CHAMBER_MREA = 0x73342A54
MAIN_RESEARCH_MREA = 0x914F1381
MINIGYRO_CHAMBER_MREA = 0x96F4CA1E
POWER_JUNCTION_MREA = 0x31C07D16
REACTOR_ACCESS_MREA = 0xB666B655
REACTOR_CORE_MREA = 0x4A6CF295
SANCTUARY_ENERGY_CONTROLLER_MREA = 0x0D032A6A
SANCTUARY_ENTRANCE_MREA = 0x47265C0B
SANCTUARY_MAP_STATION_MREA = 0x52BF89F3
SANCTUARY_TEMPLE_MREA = 0x6C363CD4
SAVE_STATION_A_MREA = 0x65B801CE
SAVE_STATION_B_MREA = 0xE32C7360
SENTINELS_PATH_MREA = 0xA4D81547
STAGING_AREA_MREA = 0x5BBF334F
TEMPLE_ACCESS_MREA = 0xC56E919A
TEMPLE_SECURITY_ACCESS_MREA = 0x42EC1D2B
TEMPLE_TRANSPORT_ACCESS_MREA = 0x625A2692
TORVUS_TRANSPORT_ACCESS_MREA = 0xF2AD74AC
TRANSIT_STATION_MREA = 0xF7424EC3
TRANSPORT_TO_AGON_WASTES_MREA = 0x35A94603
TRANSPORT_TO_TEMPLE_GROUNDS_MREA = 0xD24B673D
TRANSPORT_TO_TORVUS_BOG_MREA = 0xBB77569E
UNSEEN_WAY_MREA = 0xD5FFF2AB
VAULT_MREA = 0x52254361
VAULT_ATTACK_PORTAL_MREA = 0x1DF13149
WATCH_STATION_MREA = 0xA2406387
WATCH_STATION_ACCESS_MREA = 0x5076F9CB
WORKERS_PATH_MREA = 0x03ECA24F

NAME_TO_ID_MREA = {
    "Aerial Training Site": 0x40F7447E,
    "Aerie": 0x5D3A0001,
    "Aerie Access": 0xDF073157,
    "Aerie Transport Station": 0xBAF94A13,
    "Agon Transport Access": 0x750BBFEF,
    "Central Area Transport East": 0x1152015D,
    "Central Area Transport West": 0x70E48580,
    "Central Hive East Transport": 0xC2D7966B,
    "Central Hive West Transport": 0x6CBCD4AB,
    "Checkpoint Station": 0x844A690C,
    "Controller Access": 0xE89BDC92,
    "Culling Chamber": 0x690B786A,
    "Dynamo Access": 0x42C85AD9,
    "Dynamo Storage": 0x1F7728F8,
    "Dynamo Works": 0xC0113CE8,
    "Entrance Defense Hall": 0xA70EA82B,
    "Grand Abyss": 0x237EDE04,
    "Hall of Combat Mastery": 0x5571E89E,
    "Hazing Cliff": 0x37814F2A,
    "Hive Ammo Station": 0xF1DF78DC,
    "Hive Cache 1": 0x5F43767D,
    "Hive Cache 3": 0x072FCFBC,
    "Hive Controller Access": 0x26AC7F1E,
    "Hive Dynamo Access": 0xFBAF3B2B,
    "Hive Dynamo Works": 0xF24EF6B4,
    "Hive Energy Controller": 0x2DECC318,
    "Hive Entrance": 0xF3FA4121,
    "Hive Gyro Access": 0x2735236B,
    "Hive Gyro Chamber": 0xA3656292,
    "Hive Portal Chamber": 0x7B94B06B,
    "Hive Reactor": 0xF8DBC03D,
    "Hive Reactor Access": 0xB026CCEB,
    "Hive Save Station 1": 0xBB57222F,
    "Hive Save Station 2": 0x22B5442E,
    "Hive Summit": 0x9D804955,
    "Hive Temple": 0xA92F00B3,
    "Hive Temple Access": 0xEC875FEB,
    "Judgment Drop": 0x55C479EB,
    "Main Energy Controller": 0x57134DC2,
    "Main Gyro Chamber": 0x73342A54,
    "Main Research": 0x914F1381,
    "Minigyro Chamber": 0x96F4CA1E,
    "Power Junction": 0x31C07D16,
    "Reactor Access": 0xB666B655,
    "Reactor Core": 0x4A6CF295,
    "Sanctuary Energy Controller": 0x0D032A6A,
    "Sanctuary Entrance": 0x47265C0B,
    "Sanctuary Map Station": 0x52BF89F3,
    "Sanctuary Temple": 0x6C363CD4,
    "Save Station A": 0x65B801CE,
    "Save Station B": 0xE32C7360,
    "Sentinel's Path": 0xA4D81547,
    "Staging Area": 0x5BBF334F,
    "Temple Access": 0xC56E919A,
    "Temple Security Access": 0x42EC1D2B,
    "Temple Transport Access": 0x625A2692,
    "Torvus Transport Access": 0xF2AD74AC,
    "Transit Station": 0xF7424EC3,
    "Transport to Agon Wastes": 0x35A94603,
    "Transport to Temple Grounds": 0xD24B673D,
    "Transport to Torvus Bog": 0xBB77569E,
    "Unseen Way": 0xD5FFF2AB,
    "Vault": 0x52254361,
    "Vault Attack Portal": 0x1DF13149,
    "Watch Station": 0xA2406387,
    "Watch Station Access": 0x5076F9CB,
    "Workers Path": 0x03ECA24F,
}
# Generated by asset_id_files.py

AERIAL_TRAINING_SITE_MAPA = 0x6922BF43
AERIE_MAPA = 0x74EFFB3C
AERIE_ACCESS_MAPA = 0xF6D2CA6A
AERIE_TRANSPORT_STATION_MAPA = 0x932CB12E
AGON_TRANSPORT_ACCESS_MAPA = 0x5CDE44D2
CENTRAL_AREA_TRANSPORT_EAST_MAPA = 0x3887FA60
CENTRAL_AREA_TRANSPORT_WEST_MAPA = 0x59317EBD
CENTRAL_HIVE_EAST_TRANSPORT_MAPA = 0xEB026D56
CENTRAL_HIVE_WEST_TRANSPORT_MAPA = 0x45692F96
CHECKPOINT_STATION_MAPA = 0xAD9F9231
CONTROLLER_ACCESS_MAPA = 0xC14E27AF
CULLING_CHAMBER_MAPA = 0x40DE8357
DYNAMO_ACCESS_MAPA = 0x6B1DA1E4
DYNAMO_STORAGE_MAPA = 0x36A2D3C5
DYNAMO_WORKS_MAPA = 0xE9C4C7D5
ENTRANCE_DEFENSE_HALL_MAPA = 0x8EDB5316
GRAND_ABYSS_MAPA = 0x0AAB2539
HALL_OF_COMBAT_MASTERY_MAPA = 0x7CA413A3
HAZING_CLIFF_MAPA = 0x1E54B417
HIVE_AMMO_STATION_MAPA = 0xD80A83E1
HIVE_CACHE_1_MAPA = 0x76968D40
HIVE_CACHE_3_MAPA = 0x2EFA3481
HIVE_CONTROLLER_ACCESS_MAPA = 0x0F798423
HIVE_DYNAMO_ACCESS_MAPA = 0xD27AC016
HIVE_DYNAMO_WORKS_MAPA = 0xDB9B0D89
HIVE_ENERGY_CONTROLLER_MAPA = 0x04393825
HIVE_ENTRANCE_MAPA = 0xDA2FBA1C
HIVE_GYRO_ACCESS_MAPA = 0x0EE0D856
HIVE_GYRO_CHAMBER_MAPA = 0x8AB099AF
HIVE_PORTAL_CHAMBER_MAPA = 0x52414B56
HIVE_REACTOR_MAPA = 0xD10E3B00
HIVE_REACTOR_ACCESS_MAPA = 0x99F337D6
HIVE_SAVE_STATION_1_MAPA = 0x9282D912
HIVE_SAVE_STATION_2_MAPA = 0x0B60BF13
HIVE_SUMMIT_MAPA = 0xB455B268
HIVE_TEMPLE_MAPA = 0x80FAFB8E
HIVE_TEMPLE_ACCESS_MAPA = 0xC552A4D6
JUDGMENT_DROP_MAPA = 0x7C1182D6
MAIN_ENERGY_CONTROLLER_MAPA = 0x7EC6B6FF
MAIN_GYRO_CHAMBER_MAPA = 0x5AE1D169
MAIN_RESEARCH_MAPA = 0xB89AE8BC
MINIGYRO_CHAMBER_MAPA = 0xBF213123
POWER_JUNCTION_MAPA = 0x1815862B
REACTOR_ACCESS_MAPA = 0x9FB34D68
REACTOR_CORE_MAPA = 0x63B909A8
SANCTUARY_ENERGY_CONTROLLER_MAPA = 0x24D6D157
SANCTUARY_ENTRANCE_MAPA = 0x6EF3A736
SANCTUARY_MAP_STATION_MAPA = 0x7B6A72CE
SANCTUARY_TEMPLE_MAPA = 0x45E3C7E9
SAVE_STATION_A_MAPA = 0x4C6DFAF3
SAVE_STATION_B_MAPA = 0xCAF9885D
SENTINELS_PATH_MAPA = 0x8D0DEE7A
STAGING_AREA_MAPA = 0x726AC872
TEMPLE_ACCESS_MAPA = 0xECBB6AA7
TEMPLE_SECURITY_ACCESS_MAPA = 0x6B39E616
TEMPLE_TRANSPORT_ACCESS_MAPA = 0x4B8FDDAF
TORVUS_TRANSPORT_ACCESS_MAPA = 0xDB788F91
TRANSIT_STATION_MAPA = 0xDE97B5FE
TRANSPORT_TO_AGON_WASTES_MAPA = 0x1C7CBD3E
TRANSPORT_TO_TEMPLE_GROUNDS_MAPA = 0xFB9E9C00
TRANSPORT_TO_TORVUS_BOG_MAPA = 0x92A2ADA3
UNSEEN_WAY_MAPA = 0xFC2A0996
VAULT_MAPA = 0x7BF0B85C
VAULT_ATTACK_PORTAL_MAPA = 0x3424CA74
WATCH_STATION_MAPA = 0x8B9598BA
WATCH_STATION_ACCESS_MAPA = 0x79A302F6
WORKERS_PATH_MAPA = 0x2A395972

NAME_TO_ID_MAPA = {
    "Aerial Training Site": 0x6922BF43,
    "Aerie": 0x74EFFB3C,
    "Aerie Access": 0xF6D2CA6A,
    "Aerie Transport Station": 0x932CB12E,
    "Agon Transport Access": 0x5CDE44D2,
    "Central Area Transport East": 0x3887FA60,
    "Central Area Transport West": 0x59317EBD,
    "Central Hive East Transport": 0xEB026D56,
    "Central Hive West Transport": 0x45692F96,
    "Checkpoint Station": 0xAD9F9231,
    "Controller Access": 0xC14E27AF,
    "Culling Chamber": 0x40DE8357,
    "Dynamo Access": 0x6B1DA1E4,
    "Dynamo Storage": 0x36A2D3C5,
    "Dynamo Works": 0xE9C4C7D5,
    "Entrance Defense Hall": 0x8EDB5316,
    "Grand Abyss": 0x0AAB2539,
    "Hall of Combat Mastery": 0x7CA413A3,
    "Hazing Cliff": 0x1E54B417,
    "Hive Ammo Station": 0xD80A83E1,
    "Hive Cache 1": 0x76968D40,
    "Hive Cache 3": 0x2EFA3481,
    "Hive Controller Access": 0x0F798423,
    "Hive Dynamo Access": 0xD27AC016,
    "Hive Dynamo Works": 0xDB9B0D89,
    "Hive Energy Controller": 0x04393825,
    "Hive Entrance": 0xDA2FBA1C,
    "Hive Gyro Access": 0x0EE0D856,
    "Hive Gyro Chamber": 0x8AB099AF,
    "Hive Portal Chamber": 0x52414B56,
    "Hive Reactor": 0xD10E3B00,
    "Hive Reactor Access": 0x99F337D6,
    "Hive Save Station 1": 0x9282D912,
    "Hive Save Station 2": 0x0B60BF13,
    "Hive Summit": 0xB455B268,
    "Hive Temple": 0x80FAFB8E,
    "Hive Temple Access": 0xC552A4D6,
    "Judgment Drop": 0x7C1182D6,
    "Main Energy Controller": 0x7EC6B6FF,
    "Main Gyro Chamber": 0x5AE1D169,
    "Main Research": 0xB89AE8BC,
    "Minigyro Chamber": 0xBF213123,
    "Power Junction": 0x1815862B,
    "Reactor Access": 0x9FB34D68,
    "Reactor Core": 0x63B909A8,
    "Sanctuary Energy Controller": 0x24D6D157,
    "Sanctuary Entrance": 0x6EF3A736,
    "Sanctuary Map Station": 0x7B6A72CE,
    "Sanctuary Temple": 0x45E3C7E9,
    "Save Station A": 0x4C6DFAF3,
    "Save Station B": 0xCAF9885D,
    "Sentinel's Path": 0x8D0DEE7A,
    "Staging Area": 0x726AC872,
    "Temple Access": 0xECBB6AA7,
    "Temple Security Access": 0x6B39E616,
    "Temple Transport Access": 0x4B8FDDAF,
    "Torvus Transport Access": 0xDB788F91,
    "Transit Station": 0xDE97B5FE,
    "Transport to Agon Wastes": 0x1C7CBD3E,
    "Transport to Temple Grounds": 0xFB9E9C00,
    "Transport to Torvus Bog": 0x92A2ADA3,
    "Unseen Way": 0xFC2A0996,
    "Vault": 0x7BF0B85C,
    "Vault Attack Portal": 0x3424CA74,
    "Watch Station": 0x8B9598BA,
    "Watch Station Access": 0x79A302F6,
    "Workers Path": 0x2A395972,
}
# Generated by asset_id_files.py

AERIAL_TRAINING_SITE_INTERNAL_ID = 0x66B72B0E
AERIE_INTERNAL_ID = 0xE380B5A7
AERIE_ACCESS_INTERNAL_ID = 0xADBAE729
AERIE_TRANSPORT_STATION_INTERNAL_ID = 0xDCCFF2C6
AGON_TRANSPORT_ACCESS_INTERNAL_ID = 0x9B7F9FE8
CENTRAL_AREA_TRANSPORT_EAST_INTERNAL_ID = 0x28065DD3
CENTRAL_AREA_TRANSPORT_WEST_INTERNAL_ID = 0xF16BAE04
CENTRAL_HIVE_EAST_TRANSPORT_INTERNAL_ID = 0x3D646F91
CENTRAL_HIVE_WEST_TRANSPORT_INTERNAL_ID = 0x527BF6C1
CHECKPOINT_STATION_INTERNAL_ID = 0x46D11C3A
CONTROLLER_ACCESS_INTERNAL_ID = 0x188B5EAB
CULLING_CHAMBER_INTERNAL_ID = 0x3A73B33D
DYNAMO_ACCESS_INTERNAL_ID = 0x456FCC39
DYNAMO_STORAGE_INTERNAL_ID = 0x6390C1F6
DYNAMO_WORKS_INTERNAL_ID = 0xFB3385B5
ENTRANCE_DEFENSE_HALL_INTERNAL_ID = 0xAEBE1A9E
GRAND_ABYSS_INTERNAL_ID = 0x9C023FEE
HALL_OF_COMBAT_MASTERY_INTERNAL_ID = 0x66D7D514
HAZING_CLIFF_INTERNAL_ID = 0x401F39E7
HIVE_AMMO_STATION_INTERNAL_ID = 0x5125F5DA
HIVE_CACHE_1_INTERNAL_ID = 0x5A61C7C3
HIVE_CACHE_3_INTERNAL_ID = 0x33713618
HIVE_CONTROLLER_ACCESS_INTERNAL_ID = 0x2B60A33B
HIVE_DYNAMO_ACCESS_INTERNAL_ID = 0x6CC65DFA
HIVE_DYNAMO_WORKS_INTERNAL_ID = 0x6F096BED
HIVE_ENERGY_CONTROLLER_INTERNAL_ID = 0xA9FB8A2B
HIVE_ENTRANCE_INTERNAL_ID = 0x59145ED7
HIVE_GYRO_ACCESS_INTERNAL_ID = 0xA09DA07C
HIVE_GYRO_CHAMBER_INTERNAL_ID = 0x125001F3
HIVE_PORTAL_CHAMBER_INTERNAL_ID = 0x62E5E718
HIVE_REACTOR_INTERNAL_ID = 0x504DE08E
HIVE_REACTOR_ACCESS_INTERNAL_ID = 0x9E200B47
HIVE_SAVE_STATION_1_INTERNAL_ID = 0x8F510E80
HIVE_SAVE_STATION_2_INTERNAL_ID = 0x774E8CF0
HIVE_SUMMIT_INTERNAL_ID = 0x36DE43EA
HIVE_TEMPLE_INTERNAL_ID = 0x57FF5720
HIVE_TEMPLE_ACCESS_INTERNAL_ID = 0x5C584C23
JUDGMENT_DROP_INTERNAL_ID = 0x03D9C4AA
MAIN_ENERGY_CONTROLLER_INTERNAL_ID = 0xD4B94644
MAIN_GYRO_CHAMBER_INTERNAL_ID = 0xED4F0ADD
MAIN_RESEARCH_INTERNAL_ID = 0x57E7BDCA
MINIGYRO_CHAMBER_INTERNAL_ID = 0xBA0E2F4A
POWER_JUNCTION_INTERNAL_ID = 0x60DD0C9E
REACTOR_ACCESS_INTERNAL_ID = 0xF2D57E07
REACTOR_CORE_INTERNAL_ID = 0xB54ABB81
SANCTUARY_ENERGY_CONTROLLER_INTERNAL_ID = 0x3A186834
SANCTUARY_ENTRANCE_INTERNAL_ID = 0xFF6D683B
SANCTUARY_MAP_STATION_INTERNAL_ID = 0xF4C6417F
SANCTUARY_TEMPLE_INTERNAL_ID = 0x64177921
SAVE_STATION_A_INTERNAL_ID = 0xA4028DAD
SAVE_STATION_B_INTERNAL_ID = 0x98BC759E
SENTINELS_PATH_INTERNAL_ID = 0x0E0A4D77
STAGING_AREA_INTERNAL_ID = 0x0073DF3D
TEMPLE_ACCESS_INTERNAL_ID = 0xD767BEA0
TEMPLE_SECURITY_ACCESS_INTERNAL_ID = 0x3347D573
TEMPLE_TRANSPORT_ACCESS_INTERNAL_ID = 0x0DB49D74
TORVUS_TRANSPORT_ACCESS_INTERNAL_ID = 0x0977ED71
TRANSIT_STATION_INTERNAL_ID = 0x6363DC9D
TRANSPORT_TO_AGON_WASTES_INTERNAL_ID = 0x0172721D
TRANSPORT_TO_TEMPLE_GROUNDS_INTERNAL_ID = 0x74EC5EB4
TRANSPORT_TO_TORVUS_BOG_INTERNAL_ID = 0xE7CD5281
UNSEEN_WAY_INTERNAL_ID = 0x0DFA7E48
VAULT_INTERNAL_ID = 0x95FFACC2
VAULT_ATTACK_PORTAL_INTERNAL_ID = 0x402BFBA9
WATCH_STATION_INTERNAL_ID = 0xCA9B1A72
WATCH_STATION_ACCESS_INTERNAL_ID = 0xB9B0FF49
WORKERS_PATH_INTERNAL_ID = 0xD4D96EA3

NAME_TO_ID_INTERNAL_ID = {
    "Aerial Training Site": 0x66B72B0E,
    "Aerie": 0xE380B5A7,
    "Aerie Access": 0xADBAE729,
    "Aerie Transport Station": 0xDCCFF2C6,
    "Agon Transport Access": 0x9B7F9FE8,
    "Central Area Transport East": 0x28065DD3,
    "Central Area Transport West": 0xF16BAE04,
    "Central Hive East Transport": 0x3D646F91,
    "Central Hive West Transport": 0x527BF6C1,
    "Checkpoint Station": 0x46D11C3A,
    "Controller Access": 0x188B5EAB,
    "Culling Chamber": 0x3A73B33D,
    "Dynamo Access": 0x456FCC39,
    "Dynamo Storage": 0x6390C1F6,
    "Dynamo Works": 0xFB3385B5,
    "Entrance Defense Hall": 0xAEBE1A9E,
    "Grand Abyss": 0x9C023FEE,
    "Hall of Combat Mastery": 0x66D7D514,
    "Hazing Cliff": 0x401F39E7,
    "Hive Ammo Station": 0x5125F5DA,
    "Hive Cache 1": 0x5A61C7C3,
    "Hive Cache 3": 0x33713618,
    "Hive Controller Access": 0x2B60A33B,
    "Hive Dynamo Access": 0x6CC65DFA,
    "Hive Dynamo Works": 0x6F096BED,
    "Hive Energy Controller": 0xA9FB8A2B,
    "Hive Entrance": 0x59145ED7,
    "Hive Gyro Access": 0xA09DA07C,
    "Hive Gyro Chamber": 0x125001F3,
    "Hive Portal Chamber": 0x62E5E718,
    "Hive Reactor": 0x504DE08E,
    "Hive Reactor Access": 0x9E200B47,
    "Hive Save Station 1": 0x8F510E80,
    "Hive Save Station 2": 0x774E8CF0,
    "Hive Summit": 0x36DE43EA,
    "Hive Temple": 0x57FF5720,
    "Hive Temple Access": 0x5C584C23,
    "Judgment Drop": 0x03D9C4AA,
    "Main Energy Controller": 0xD4B94644,
    "Main Gyro Chamber": 0xED4F0ADD,
    "Main Research": 0x57E7BDCA,
    "Minigyro Chamber": 0xBA0E2F4A,
    "Power Junction": 0x60DD0C9E,
    "Reactor Access": 0xF2D57E07,
    "Reactor Core": 0xB54ABB81,
    "Sanctuary Energy Controller": 0x3A186834,
    "Sanctuary Entrance": 0xFF6D683B,
    "Sanctuary Map Station": 0xF4C6417F,
    "Sanctuary Temple": 0x64177921,
    "Save Station A": 0xA4028DAD,
    "Save Station B": 0x98BC759E,
    "Sentinel's Path": 0x0E0A4D77,
    "Staging Area": 0x0073DF3D,
    "Temple Access": 0xD767BEA0,
    "Temple Security Access": 0x3347D573,
    "Temple Transport Access": 0x0DB49D74,
    "Torvus Transport Access": 0x0977ED71,
    "Transit Station": 0x6363DC9D,
    "Transport to Agon Wastes": 0x0172721D,
    "Transport to Temple Grounds": 0x74EC5EB4,
    "Transport to Torvus Bog": 0xE7CD5281,
    "Unseen Way": 0x0DFA7E48,
    "Vault": 0x95FFACC2,
    "Vault Attack Portal": 0x402BFBA9,
    "Watch Station": 0xCA9B1A72,
    "Watch Station Access": 0xB9B0FF49,
    "Workers Path": 0xD4D96EA3,
}

DOCK_NAMES = {
    "Aerial Training Site": {
        "South": 0,
        "West_0L": 1,
        "East": 2,
        "West_0O": 3,
        "VirtualNorth1": 4,
    },
    "Aerie": {
        "Docks_Floor": 0,
        "VirtualArenaDock": 1,
        "VirtualUnderStatueDock": 2,
    },
    "Aerie Access": {
        "Floor": 0,
        "Ceiling": 1,
    },
    "Aerie Transport Station": {
        "South": 0,
        "Ceiling": 1,
    },
    "Agon Transport Access": {
        "East": 0,
        "West": 1,
    },
    "Central Area Transport East": {
        "group1_West_04 (Top)": 0,
        "group1_West_07 (Bottom)": 1,
    },
    "Central Area Transport West": {
        "East_Top": 0,
        "East_Bottom": 1,
    },
    "Central Hive East Transport": {
        "group1_West_04 (Top)": 0,
        "group1_West_07 (Bottom)": 1,
    },
    "Central Hive West Transport": {
        "East_Top": 0,
        "East_Bottom": 1,
    },
    "Checkpoint Station": {
        "North": 0,
        "South": 1,
    },
    "Controller Access": {
        "North": 0,
        "South1": 1,
    },
    "Culling Chamber": {
        "EastHall": 0,
        "EastElevator": 1,
        "West": 2,
        "VirtualNorth": 3,
    },
    "Dynamo Access": {
        "West": 0,
        "East": 1,
    },
    "Dynamo Storage": {
        "group1_West": 0,
        "VirtualWest": 1,
    },
    "Dynamo Works": {
        "East 0E": 0,
        "West1 0F": 1,
        "South2 0H": 2,
        "East2 00_Pickup C": 3,
        "VirtualNorth": 4,
    },
    "Entrance Defense Hall": {
        "North2": 0,
        "South": 1,
    },
    "Grand Abyss": {
        "East": 0,
        "VirtualNorth": 1,
        "Ceiling": 2,
    },
    "Hall of Combat Mastery": {
        "EastHall": 0,
        "EastElevator": 1,
        "West": 2,
        "VirtualNorth": 3,
    },
    "Hazing Cliff": {
        "East": 0,
        "West": 1,
    },
    "Hive Ammo Station": {
        "South": 0,
        "Ceiling": 1,
    },
    "Hive Cache 1": {
        "South": 0,
    },
    "Hive Cache 3": {
        "group1_West": 0,
        "VirtualWest": 1,
    },
    "Hive Controller Access": {
        "North": 0,
        "South1": 1,
    },
    "Hive Dynamo Access": {
        "West": 0,
        "East": 1,
    },
    "Hive Dynamo Works": {
        "East": 0,
        "West1": 1,
        "South2 (Disabled)": 2,
        "East2": 3,
        "VirtualNorth": 4,
    },
    "Hive Energy Controller": {
        "North": 0,
    },
    "Hive Entrance": {
        "North": 0,
        "South": 1,
    },
    "Hive Gyro Access": {
        "North": 0,
        "South": 1,
    },
    "Hive Gyro Chamber": {
        "South": 0,
        "North1": 1,
        "West_Save": 2,
        "East1": 3,
        "West21": 4,
    },
    "Hive Portal Chamber": {
        "West": 0,
        "VirtualDock_South": 1,
        "VirtualDock_North_Right": 2,
        "VirtualDock_North_Left": 3,
        "VirtualDock_North_Middle": 4,
    },
    "Hive Reactor": {
        "North": 0,
        "East": 1,
        "South": 2,
        "North2": 3,
    },
    "Hive Reactor Access": {
        "North": 0,
        "South": 1,
    },
    "Hive Save Station 1": {
        "South": 0,
    },
    "Hive Save Station 2": {
        "East": 0,
    },
    "Hive Summit": {
        "Docks_Floor": 0,
        "VirtualArenaDock": 1,
        "VirtualUnderStatueDock": 2,
    },
    "Hive Temple": {
        "South": 0,
        "West": 1,
        "East": 2,
        "North": 3,
    },
    "Hive Temple Access": {
        "South": 0,
        "North": 1,
    },
    "Judgment Drop": {
        "East": 0,
        "VirtualNorth": 1,
    },
    "Main Energy Controller": {
        "SouthLight1": 0,
        "VirtualNorth": 1,
        "North1": 2,
    },
    "Main Gyro Chamber": {
        "South": 0,
        "North1": 1,
        "West_Save": 2,
        "East1": 3,
        "West21": 4,
    },
    "Main Research": {
        "West to 0l_cliff_hall": 0,
        "West1 to 0p_cliff_hall": 1,
        "East2 to 0m_cliff_hall": 2,
        "VirtualNorth": 3,
        "VirtualNorth1": 4,
        "North": 5,
    },
    "Minigyro Chamber": {
        "West": 0,
        "East": 1,
    },
    "Power Junction": {
        "North2": 0,
        "South": 1,
    },
    "Reactor Access": {
        "North": 0,
        "South": 1,
    },
    "Reactor Core": {
        "North": 0,
        "East": 1,
        "West": 2,
        "South": 3,
        "North2": 4,
    },
    "Sanctuary Energy Controller": {
        "North": 0,
        "North1 (to 08)": 1,
    },
    "Sanctuary Entrance": {
        "North": 0,
        "South": 1,
    },
    "Sanctuary Map Station": {
        "South": 0,
    },
    "Sanctuary Temple": {
        "South": 0,
        "West": 1,
        "East": 2,
        "North": 3,
    },
    "Save Station A": {
        "South": 0,
    },
    "Save Station B": {
        "East": 0,
    },
    "Sentinel's Path": {
        "East": 0,
        "North": 1,
    },
    "Staging Area": {
        "West": 0,
        "West1": 1,
        "East2": 2,
        "VirtualNorth": 3,
        "VirtualNorth1": 4,
        "North": 5,
    },
    "Temple Access": {
        "South": 0,
        "North": 1,
    },
    "Temple Security Access": {
        "East": 0,
        "North": 1,
    },
    "Temple Transport Access": {
        "South1": 0,
        "North1": 1,
    },
    "Torvus Transport Access": {
        "East": 0,
        "West": 1,
    },
    "Transit Station": {
        "West": 0,
        "East": 1,
        "VirtualDock_South": 2,
        "VirtualDock_North_Right": 3,
        "VirtualDock_North_Left": 4,
        "VirtualDock_North_Middle": 5,
    },
    "Transport to Agon Wastes": {
        "West": 0,
    },
    "Transport to Temple Grounds": {
        "North": 0,
    },
    "Transport to Torvus Bog": {
        "East": 0,
    },
    "Unseen Way": {
        "West": 0,
        "East": 1,
    },
    "Vault": {
        "East": 0,
        "VirtualWest": 1,
        "VirtualEast": 2,
    },
    "Vault Attack Portal": {
        "East": 0,
        "VirtualWest": 1,
        "VirtualEast": 2,
    },
    "Watch Station": {
        "South": 0,
        "WestDown": 1,
        "East": 2,
        "WestUp": 3,
        "VirtualNorth1": 4,
    },
    "Watch Station Access": {
        "East": 0,
        "West": 1,
    },
    "Workers Path": {
        "West": 0,
        "North": 1,
    },
}



from retro_data_structures.base_resource import AssetId

SUIT_ASSETS: dict[str, dict[AssetId, str]] = {
    "varia": {
        0x788432DA: "samus_varia_visor.TXTR",
        0xC2DE6C2A: "samus_varia_visor_emissive.TXTR",
        0x86FF8630: "samus_varia_visor_polish.TXTR",
        0x12B6539F: "samus_varia_banding.TXTR",
        0x42DFBEBF: "samus_varia_banding_2.TXTR",
        0x604D4DC5: "samus_varia_flex.TXTR",
        0xE3001044: "samus_varia_flex_polish.TXTR",
        0xE8AF7174: "samus_varia_armor.TXTR",
        0xFFD9D212: "samus_varia_armor_polish.TXTR",
        0x8FF8E517: "samus_varia_trim.TXTR",
        0x2883811B: "samus_varia_trim_polish.TXTR",
        0x355E4212: "samus_varia_metallic.TXTR",
        0x0EF3BA76: "samus_varia_morph_shell.TXTR",
        0x0CC73555: "samus_varia_morph_emissive.TXTR",
        0x3C214DF7: "samus_varia_morph_banding.TXTR",
        0xAAEC3745: "samus_varia_morph_metallic.TXTR",
        0x1E5621F5: "samus_varia_low_res_armor.TXTR",
        0x97FEE0A8: "samus_varia_low_res_armor_polish.TXTR",
        0x23B19B14: "samus_varia_low_res_emissive.TXTR",
        0xDD1473FC: "samus_varia_low_res_metallic.TXTR",
        0x2777D332: "samus_varia_morph_2_shell.TXTR",
        0xEB669581: "samus_varia_morph_2_shell_polish.TXTR",
        0xA29AEF93: "samus_varia_morph_3_shell.TXTR",
        0x9643B175: "samus_varia_morph_3_shell_polish.TXTR",
        0x2F566CEC: "samus_morph_2_3_metallic.TXTR",
        0x9BD4E4B3: "samus_varia_armor_polish_2.TXTR",
        0xB29C1225: "samus_varia_left_arm_metallic.TXTR",
    },
    "dark": {
        0x022045C3: "samus_dark_visor.TXTR",
        0xA3BB66A5: "samus_dark_visor_emissive.TXTR",
        0x27805BC6: "samus_dark_visor_scanlines.TXTR",
        0xB29C1225: "samus_dark_visor_metallic.TXTR",
        0x9FCF0D60: "samus_dark_spot_accent.TXTR",
        0xB95FE642: "samus_dark_armor.TXTR",
        0x3B843F46: "samus_dark_armor_metallic.TXTR",
        0xA283E265: "samus_dark_backpack.TXTR",
        0x9255BD83: "samus_dark_morph.TXTR",
        0x33CE9EE5: "samus_dark_morph_emissive.TXTR",
        0x52E13615: "samus_dark_morph_polish.TXTR",
        0x719F387E: "samus_dark_morph_trim.TXTR",
        0xD0041B18: "samus_dark_morph_trim_2.TXTR",
        0x59C822A0: "samus_dark_spider.TXTR",
        0xF85301C6: "samus_dark_spider_emissive.TXTR",
        0x8CF8043C: "samus_dark_spider_polish.TXTR",
        0x21722E06: "samus_dark_spider_glass.TXTR",
        0x459769C7: "samus_dark_spider_glass_polish.TXTR",
        0x7F5781D8: "samus_dark_low_res_armor.TXTR",
        0xFF45E6C4: "samus_dark_low_res_armor_emissive.TXTR",
        0x091ACC33: "samus_dark_low_res_backpack.TXTR",
        0xDD1473FC: "samus_dark_low_res_armor_metallic.TXTR",
        0x2F566CEC: "samus_morph_2_3_metallic.TXTR",
        0x80A7CF0D: "samus_dark_left_arm_reflective.TXTR",
        0xD31B3FB2: "samus_dark_left_arm_trim.TXTR",
        0xB6728B45: "samus_dark_left_arm_trim_2.TXTR",
        0xB34CE6A0: "samus_dark_mini_emissive.TXTR",
        0x587282CC: "samus_grapple_gear.TXTR",
        0x1BA9033F: "samus_grapple_gear_metallic.TXTR",
    },
    "light": {
        0xCB737809: "samus_light_visor_core_on.TXTR",
        0xF5E3D9FF: "samus_light_visor_core_off.TXTR",
        0x0B7D7395: "samus_light_visor_core_emissive.TXTR",
        0x8048F092: "samus_light_visor_streaks.TXTR",
        0xADA9C079: "samus_light_core_beam.TXTR",
        0xC2B83ED1: "samus_light_core_beam_pattern.TXTR",
        0x5B3271CA: "samus_light_armor.TXTR",
        0xC35540DE: "samus_light_armor_metallic.TXTR",
        0x091A32D6: "samus_light_morph_shell.TXTR",
        0xC6A37961: "samus_light_morph_emissive.TXTR",
        0x0662A1C7: "samus_light_morph_metallic.TXTR",
        0x8A598DD2: "samus_light_low_res_armor.TXTR",
        0x95E79836: "samus_light_low_res_armor_emissive.TXTR",
        0x0C32C6DA: "samus_light_left_arm.TXTR",
        0xC9B164A1: "samus_light_left_arm_trim.TXTR",
        0x087D0789: "samus_light_left_arm_trim_2.TXTR",
        0xA240A5D3: "samus_light_mini_core_off.TXTR",
        0xAA2D0CCF: "samus_light_mini_emissive.TXTR",
    },
}



import dataclasses

from retro_data_structures.enums import echoes
from retro_data_structures.properties.echoes.archetypes.DamageVulnerability import DamageVulnerability
from retro_data_structures.properties.echoes.archetypes.WeaponVulnerability import WeaponVulnerability

reflect = WeaponVulnerability(damage_multiplier=0, effect=echoes.Effect.Reflect)
vulnerable = WeaponVulnerability(damage_multiplier=100, effect=echoes.Effect.Normal)
immune = WeaponVulnerability(damage_multiplier=0, effect=echoes.Effect.Normal, ignore_radius=True)
vulnerable_no_splash = WeaponVulnerability(damage_multiplier=100.0, effect=echoes.Effect.Normal, ignore_radius=True)


resist_all_vuln = DamageVulnerability(
    power=reflect, dark=reflect, light=reflect, annihilator=reflect,
    power_charge=reflect, entangler=reflect, light_blast=reflect, sonic_boom=reflect,
    super_missle=reflect, black_hole=reflect, sunburst=reflect, imploder=reflect,

    boost_ball=immune, cannon_ball=immune, screw_attack=immune, bomb=immune, power_bomb=immune,
    missile=reflect, phazon=reflect, ai=immune, poison_water=immune, dark_water=immune, lava=immune,
    area_damage_hot=immune, area_damage_cold=immune, area_damage_dark=immune, area_damage_light=immune,
    weapon_vulnerability=immune, normal_safe_zone=immune,
)

normal_vuln = dataclasses.replace(
    resist_all_vuln,
    power=vulnerable, dark=vulnerable, light=vulnerable, annihilator=vulnerable,
    power_charge=vulnerable, entangler=vulnerable, light_blast=vulnerable, sonic_boom=vulnerable,
    super_missle=vulnerable, black_hole=vulnerable, sunburst=vulnerable, imploder=vulnerable,

    missile=vulnerable, bomb=vulnerable, power_bomb=vulnerable,
)



# Generated by asset_id_files.py

AGON_WASTES_MLVL = 0x42B935E4
GREAT_TEMPLE_MLVL = 0x863FCD72
SANCTUARY_FORTRESS_MLVL = 0x1BAA96C2
TEMPLE_GROUNDS_MLVL = 0x3BFA3EFF
TORVUS_BOG_MLVL = 0x3DFD2249

NAME_TO_ID_MLVL = {
    "Agon Wastes": 0x42B935E4,
    "Great Temple": 0x863FCD72,
    "Sanctuary Fortress": 0x1BAA96C2,
    "Temple Grounds": 0x3BFA3EFF,
    "Torvus Bog": 0x3DFD2249,
}
# Generated by asset_id_files.py

AGON_WASTES_MAPW = 0x38DBF6A5
GREAT_TEMPLE_MAPW = 0xFC5D0E33
SANCTUARY_FORTRESS_MAPW = 0x61C85583
TEMPLE_GROUNDS_MAPW = 0x4198FDBE
TORVUS_BOG_MAPW = 0x479FE108

NAME_TO_ID_MAPW = {
    "Agon Wastes": 0x38DBF6A5,
    "Great Temple": 0xFC5D0E33,
    "Sanctuary Fortress": 0x61C85583,
    "Temple Grounds": 0x4198FDBE,
    "Torvus Bog": 0x479FE108,
}

_DEDICATED_FILES = {
    "Agon Wastes": ".agon_wastes",
    "Great Temple": ".great_temple",
    "Sanctuary Fortress": ".sanctuary_fortress",
    "Temple Grounds": ".temple_grounds",
    "Torvus Bog": ".torvus_bog",
}


def load_dedicated_file(world_name: str):
    import importlib
    return importlib.import_module(
        _DEDICATED_FILES[world_name],
        ".".join(__name__.split(".")[:-1]),
    )



from open_prime_rando.dol_patching.prime1.dol_patches import Prime1DolVersion

ALL_VERSIONS = [
    Prime1DolVersion(
        version="0-00",
        description="GC NTSC 0-00",
        build_string_address=0x803cc588,
        build_string=b"!#$MetroidBuildInfo!#$Build v1.088 10/29/2002 2:21:25",
        sda2_base=0x805b1d20,
        sda13_base=0x805aebc0,
        cplayer_vtable=0x803d96e8,
        message_receiver_string_ref=0x803efb90,
    ),
    Prime1DolVersion(
        version="0-01",
        description="GC NTSC 0-01",
        build_string_address=0x803cc768,
        build_string=b"!#$MetroidBuildInfo!#$Build v1.093 11/5/2002 19:50:01",
        sda2_base=0x805b1f00,
        sda13_base=0x805aeda0,
        cplayer_vtable=0x803d98c8,
        message_receiver_string_ref=0x803efd70,
    ),
    Prime1DolVersion(
        version="0-02",
        description="GC NTSC 0-02",
        build_string_address=0x803cd648,
        build_string=b"!#$MetroidBuildInfo!#$Build v1.111 3/10/2003 17:56:21",
        sda2_base=0x805b2de0,
        sda13_base=0x805afc40,
        cplayer_vtable=0x803da7a8,
        message_receiver_string_ref=0x803f0ba8,
    ),
    Prime1DolVersion(
        version="pal",
        description="GC PAL",
        build_string_address=0x803b6924,
        build_string=b"!#$MetroidBuildInfo!#$Build v1.110 2/4/2003 22:16:07",
        sda2_base=0x80473e60,
        sda13_base=0x80470c60,
        cplayer_vtable=0x803c4b88,
        message_receiver_string_ref=0x803d7a28,
    ),
    Prime1DolVersion(
        version="kor",
        description="GC NTSC-K",
        build_string_address=0x803cc688,
        build_string=b"!#$MetroidBuildInfo!#$Build v1.097 12/19/2002 16:03:43",
        sda2_base=0x805b1a00,
        sda13_base=0x805ae8a0,
        cplayer_vtable=0x803d97e8,
        message_receiver_string_ref=0x803efc90,
    ),
    Prime1DolVersion(
        version="jpn",
        description="GC NTSC-J",
        build_string_address=0x803b86cc,
        build_string=b"!#$MetroidBuildInfo!#$Build v1.111 2/11/2003 10:03:22",
        sda2_base=0x8059ae00,
        sda13_base=0x80597c20,
        cplayer_vtable=0x803c5b28,
        message_receiver_string_ref=0x803d89c8,
    ),
]



# Generated by asset_id_files.py

SCANDUMMY_MREA = 0x131C3388
ABANDONED_BASE_MREA = 0xC6F4E0C2
ACCURSED_LAKE_MREA = 0x9FD196DF
AGON_TRANSPORT_ACCESS_MREA = 0xA391C9AB
BASE_ACCESS_MREA = 0x686F5A1B
COLLAPSED_TUNNEL_MREA = 0x5B92D146
COMMAND_CHAMBER_MREA = 0xD627000B
COMMUNICATION_AREA_MREA = 0x635E8DA1
DEFILED_SHRINE_MREA = 0x16E116B4
DYNAMO_CHAMBER_MREA = 0xB4C067A7
FORTRESS_TRANSPORT_ACCESS_MREA = 0x70E5E6DD
GFMC_COMPOUND_MREA = 0x57757AD5
GATEWAY_ACCESS_MREA = 0x84324C98
GRAND_WINDCHAMBER_MREA = 0xAD70917D
HALL_OF_EYES_MREA = 0x476BA84C
HALL_OF_HONORED_DEAD_MREA = 0xB8B34634
HIVE_ACCESS_TUNNEL_MREA = 0xB1140C24
HIVE_CHAMBER_A_MREA = 0x50B372A5
HIVE_CHAMBER_B_MREA = 0x1D7BD3AE
HIVE_CHAMBER_C_MREA = 0xFB843824
HIVE_SAVE_STATION_MREA = 0x1461DC2F
HIVE_STORAGE_MREA = 0x6367D577
HIVE_TRANSPORT_AREA_MREA = 0x941F873A
HIVE_TUNNEL_MREA = 0x1582EC4A
INDUSTRIAL_SITE_MREA = 0x62AC8AC4
ING_RELIQUARY_MREA = 0x749E82E3
ING_WINDCHAMBER_MREA = 0xCDEF2BF1
LAKE_ACCESS_MREA = 0x688AB8AE
LANDING_SITE_MREA = 0x62B0D67D
MEETING_GROUNDS_MREA = 0x9B5EFA75
PATH_OF_EYES_MREA = 0xEE4732BE
PATH_OF_HONOR_MREA = 0x7B4D31DB
PHAZON_GROUNDS_MREA = 0x645EF243
PHAZON_PIT_MREA = 0x1E332000
PLAIN_OF_DARK_WORSHIP_MREA = 0x0405EBA4
PORTAL_SITE_MREA = 0xDA37FF97
PROFANE_PATH_MREA = 0x64E640D6
RELIQUARY_ACCESS_MREA = 0x8540CAD4
RELIQUARY_GROUNDS_MREA = 0xFC8FC0A4
SACRED_BRIDGE_MREA = 0xBABCDB22
SACRED_PATH_MREA = 0xC23CFFBD
SERVICE_ACCESS_MREA = 0x9FB7503C
SHRINE_ACCESS_MREA = 0x1F1D07DF
SKY_TEMPLE_GATEWAY_MREA = 0x87D35EE4
STORAGE_CAVERN_A_MREA = 0x3800CF82
STORAGE_CAVERN_B_MREA = 0xBE94BD2C
TEMPLE_ASSEMBLY_SITE_MREA = 0x4B4E5911
TEMPLE_TRANSPORT_A_MREA = 0x503A0640
TEMPLE_TRANSPORT_B_MREA = 0x4CC37F4A
TEMPLE_TRANSPORT_C_MREA = 0xADED752E
TORVUS_TRANSPORT_ACCESS_MREA = 0xA8391EAD
TRANSPORT_TO_AGON_WASTES_MREA = 0x62FF94EE
TRANSPORT_TO_SANCTUARY_FORTRESS_MREA = 0xCDF7686B
TRANSPORT_TO_TORVUS_BOG_MREA = 0xAC32F338
TROOPER_SECURITY_STATION_MREA = 0x55EE6DC3
WAR_RITUAL_GROUNDS_MREA = 0xAA77EAAD
WINDCHAMBER_GATEWAY_MREA = 0x75318D5E
WINDCHAMBER_TUNNEL_MREA = 0x9A633BBF
GAME_END_PART1_MREA = 0x1ED8D8B1
GAME_END_PART2_MREA = 0x984CAA1F
GAME_END_PART3_MREA = 0x531079BA
GAME_END_PART4_MREA = 0x4E154902
GAME_END_PART5_MREA = 0x85499AA7

NAME_TO_ID_MREA = {
    "00_scandummy": 0x131C3388,
    "Abandoned Base": 0xC6F4E0C2,
    "Accursed Lake": 0x9FD196DF,
    "Agon Transport Access": 0xA391C9AB,
    "Base Access": 0x686F5A1B,
    "Collapsed Tunnel": 0x5B92D146,
    "Command Chamber": 0xD627000B,
    "Communication Area": 0x635E8DA1,
    "Defiled Shrine": 0x16E116B4,
    "Dynamo Chamber": 0xB4C067A7,
    "Fortress Transport Access": 0x70E5E6DD,
    "GFMC Compound": 0x57757AD5,
    "Gateway Access": 0x84324C98,
    "Grand Windchamber": 0xAD70917D,
    "Hall of Eyes": 0x476BA84C,
    "Hall of Honored Dead": 0xB8B34634,
    "Hive Access Tunnel": 0xB1140C24,
    "Hive Chamber A": 0x50B372A5,
    "Hive Chamber B": 0x1D7BD3AE,
    "Hive Chamber C": 0xFB843824,
    "Hive Save Station": 0x1461DC2F,
    "Hive Storage": 0x6367D577,
    "Hive Transport Area": 0x941F873A,
    "Hive Tunnel": 0x1582EC4A,
    "Industrial Site": 0x62AC8AC4,
    "Ing Reliquary": 0x749E82E3,
    "Ing Windchamber": 0xCDEF2BF1,
    "Lake Access": 0x688AB8AE,
    "Landing Site": 0x62B0D67D,
    "Meeting Grounds": 0x9B5EFA75,
    "Path of Eyes": 0xEE4732BE,
    "Path of Honor": 0x7B4D31DB,
    "Phazon Grounds": 0x645EF243,
    "Phazon Pit": 0x1E332000,
    "Plain of Dark Worship": 0x0405EBA4,
    "Portal Site": 0xDA37FF97,
    "Profane Path": 0x64E640D6,
    "Reliquary Access": 0x8540CAD4,
    "Reliquary Grounds": 0xFC8FC0A4,
    "Sacred Bridge": 0xBABCDB22,
    "Sacred Path": 0xC23CFFBD,
    "Service Access": 0x9FB7503C,
    "Shrine Access": 0x1F1D07DF,
    "Sky Temple Gateway": 0x87D35EE4,
    "Storage Cavern A": 0x3800CF82,
    "Storage Cavern B": 0xBE94BD2C,
    "Temple Assembly Site": 0x4B4E5911,
    "Temple Transport A": 0x503A0640,
    "Temple Transport B": 0x4CC37F4A,
    "Temple Transport C": 0xADED752E,
    "Torvus Transport Access": 0xA8391EAD,
    "Transport to Agon Wastes": 0x62FF94EE,
    "Transport to Sanctuary Fortress": 0xCDF7686B,
    "Transport to Torvus Bog": 0xAC32F338,
    "Trooper Security Station": 0x55EE6DC3,
    "War Ritual Grounds": 0xAA77EAAD,
    "Windchamber Gateway": 0x75318D5E,
    "Windchamber Tunnel": 0x9A633BBF,
    "game_end_part1": 0x1ED8D8B1,
    "game_end_part2": 0x984CAA1F,
    "game_end_part3": 0x531079BA,
    "game_end_part4": 0x4E154902,
    "game_end_part5": 0x85499AA7,
}
# Generated by asset_id_files.py

SCANDUMMY_MAPA = 0x3AC9C8B5
ABANDONED_BASE_MAPA = 0xEF211BFF
ACCURSED_LAKE_MAPA = 0xB6046DE2
AGON_TRANSPORT_ACCESS_MAPA = 0x8A443296
BASE_ACCESS_MAPA = 0x41BAA126
COLLAPSED_TUNNEL_MAPA = 0x72472A7B
COMMAND_CHAMBER_MAPA = 0xFFF2FB36
COMMUNICATION_AREA_MAPA = 0x4A8B769C
DEFILED_SHRINE_MAPA = 0x3F34ED89
DYNAMO_CHAMBER_MAPA = 0x9D159C9A
FORTRESS_TRANSPORT_ACCESS_MAPA = 0x59301DE0
GFMC_COMPOUND_MAPA = 0x7EA081E8
GATEWAY_ACCESS_MAPA = 0xADE7B7A5
GRAND_WINDCHAMBER_MAPA = 0x84A56A40
HALL_OF_EYES_MAPA = 0x6EBE5371
HALL_OF_HONORED_DEAD_MAPA = 0x9166BD09
HIVE_ACCESS_TUNNEL_MAPA = 0x98C1F719
HIVE_CHAMBER_A_MAPA = 0x79668998
HIVE_CHAMBER_B_MAPA = 0x34AE2893
HIVE_CHAMBER_C_MAPA = 0xD251C319
HIVE_SAVE_STATION_MAPA = 0x3DB42712
HIVE_STORAGE_MAPA = 0x4AB22E4A
HIVE_TRANSPORT_AREA_MAPA = 0xBDCA7C07
HIVE_TUNNEL_MAPA = 0x3C571777
INDUSTRIAL_SITE_MAPA = 0x4B7971F9
ING_RELIQUARY_MAPA = 0x5D4B79DE
ING_WINDCHAMBER_MAPA = 0xE43AD0CC
LAKE_ACCESS_MAPA = 0x415F4393
LANDING_SITE_MAPA = 0x4B652D40
MEETING_GROUNDS_MAPA = 0xB28B0148
PATH_OF_EYES_MAPA = 0xC792C983
PATH_OF_HONOR_MAPA = 0x5298CAE6
PHAZON_GROUNDS_MAPA = 0x4D8B097E
PHAZON_PIT_MAPA = 0x37E6DB3D
PLAIN_OF_DARK_WORSHIP_MAPA = 0x2DD01099
PORTAL_SITE_MAPA = 0xF3E204AA
PROFANE_PATH_MAPA = 0x4D33BBEB
RELIQUARY_ACCESS_MAPA = 0xAC9531E9
RELIQUARY_GROUNDS_MAPA = 0xD55A3B99
SACRED_BRIDGE_MAPA = 0x9369201F
SACRED_PATH_MAPA = 0xEBE90480
SERVICE_ACCESS_MAPA = 0xB662AB01
SHRINE_ACCESS_MAPA = 0x36C8FCE2
SKY_TEMPLE_GATEWAY_MAPA = 0xAE06A5D9
STORAGE_CAVERN_A_MAPA = 0x11D534BF
STORAGE_CAVERN_B_MAPA = 0x97414611
TEMPLE_ASSEMBLY_SITE_MAPA = 0x629BA22C
TEMPLE_TRANSPORT_A_MAPA = 0x79EFFD7D
TEMPLE_TRANSPORT_B_MAPA = 0x65168477
TEMPLE_TRANSPORT_C_MAPA = 0x84388E13
TORVUS_TRANSPORT_ACCESS_MAPA = 0x81ECE590
TRANSPORT_TO_AGON_WASTES_MAPA = 0x4B2A6FD3
TRANSPORT_TO_SANCTUARY_FORTRESS_MAPA = 0xE4229356
TRANSPORT_TO_TORVUS_BOG_MAPA = 0x85E70805
TROOPER_SECURITY_STATION_MAPA = 0x7C3B96FE
WAR_RITUAL_GROUNDS_MAPA = 0x83A21190
WINDCHAMBER_GATEWAY_MAPA = 0x5CE47663
WINDCHAMBER_TUNNEL_MAPA = 0xB3B6C082
GAME_END_PART1_MAPA = 0x370D238C
GAME_END_PART2_MAPA = 0xB1995122
GAME_END_PART3_MAPA = 0x7AC58287
GAME_END_PART4_MAPA = 0x67C0B23F
GAME_END_PART5_MAPA = 0xAC9C619A

NAME_TO_ID_MAPA = {
    "00_scandummy": 0x3AC9C8B5,
    "Abandoned Base": 0xEF211BFF,
    "Accursed Lake": 0xB6046DE2,
    "Agon Transport Access": 0x8A443296,
    "Base Access": 0x41BAA126,
    "Collapsed Tunnel": 0x72472A7B,
    "Command Chamber": 0xFFF2FB36,
    "Communication Area": 0x4A8B769C,
    "Defiled Shrine": 0x3F34ED89,
    "Dynamo Chamber": 0x9D159C9A,
    "Fortress Transport Access": 0x59301DE0,
    "GFMC Compound": 0x7EA081E8,
    "Gateway Access": 0xADE7B7A5,
    "Grand Windchamber": 0x84A56A40,
    "Hall of Eyes": 0x6EBE5371,
    "Hall of Honored Dead": 0x9166BD09,
    "Hive Access Tunnel": 0x98C1F719,
    "Hive Chamber A": 0x79668998,
    "Hive Chamber B": 0x34AE2893,
    "Hive Chamber C": 0xD251C319,
    "Hive Save Station": 0x3DB42712,
    "Hive Storage": 0x4AB22E4A,
    "Hive Transport Area": 0xBDCA7C07,
    "Hive Tunnel": 0x3C571777,
    "Industrial Site": 0x4B7971F9,
    "Ing Reliquary": 0x5D4B79DE,
    "Ing Windchamber": 0xE43AD0CC,
    "Lake Access": 0x415F4393,
    "Landing Site": 0x4B652D40,
    "Meeting Grounds": 0xB28B0148,
    "Path of Eyes": 0xC792C983,
    "Path of Honor": 0x5298CAE6,
    "Phazon Grounds": 0x4D8B097E,
    "Phazon Pit": 0x37E6DB3D,
    "Plain of Dark Worship": 0x2DD01099,
    "Portal Site": 0xF3E204AA,
    "Profane Path": 0x4D33BBEB,
    "Reliquary Access": 0xAC9531E9,
    "Reliquary Grounds": 0xD55A3B99,
    "Sacred Bridge": 0x9369201F,
    "Sacred Path": 0xEBE90480,
    "Service Access": 0xB662AB01,
    "Shrine Access": 0x36C8FCE2,
    "Sky Temple Gateway": 0xAE06A5D9,
    "Storage Cavern A": 0x11D534BF,
    "Storage Cavern B": 0x97414611,
    "Temple Assembly Site": 0x629BA22C,
    "Temple Transport A": 0x79EFFD7D,
    "Temple Transport B": 0x65168477,
    "Temple Transport C": 0x84388E13,
    "Torvus Transport Access": 0x81ECE590,
    "Transport to Agon Wastes": 0x4B2A6FD3,
    "Transport to Sanctuary Fortress": 0xE4229356,
    "Transport to Torvus Bog": 0x85E70805,
    "Trooper Security Station": 0x7C3B96FE,
    "War Ritual Grounds": 0x83A21190,
    "Windchamber Gateway": 0x5CE47663,
    "Windchamber Tunnel": 0xB3B6C082,
    "game_end_part1": 0x370D238C,
    "game_end_part2": 0xB1995122,
    "game_end_part3": 0x7AC58287,
    "game_end_part4": 0x67C0B23F,
    "game_end_part5": 0xAC9C619A,
}
# Generated by asset_id_files.py

SCANDUMMY_INTERNAL_ID = 0x775664A5
ABANDONED_BASE_INTERNAL_ID = 0x89D924A7
ACCURSED_LAKE_INTERNAL_ID = 0x012F9639
AGON_TRANSPORT_ACCESS_INTERNAL_ID = 0x650909ED
BASE_ACCESS_INTERNAL_ID = 0x07CE0C72
COLLAPSED_TUNNEL_INTERNAL_ID = 0x1671BCCE
COMMAND_CHAMBER_INTERNAL_ID = 0xCFB06832
COMMUNICATION_AREA_INTERNAL_ID = 0xDCEC348B
DEFILED_SHRINE_INTERNAL_ID = 0xB23C2110
DYNAMO_CHAMBER_INTERNAL_ID = 0x600D7227
FORTRESS_TRANSPORT_ACCESS_INTERNAL_ID = 0xF080D688
GFMC_COMPOUND_INTERNAL_ID = 0xEAA44A69
GATEWAY_ACCESS_INTERNAL_ID = 0xBA85FBF7
GRAND_WINDCHAMBER_INTERNAL_ID = 0xDD711FE2
HALL_OF_EYES_INTERNAL_ID = 0x11F7FAE1
HALL_OF_HONORED_DEAD_INTERNAL_ID = 0x1DA26BFF
HIVE_ACCESS_TUNNEL_INTERNAL_ID = 0x8CF4EFF5
HIVE_CHAMBER_A_INTERNAL_ID = 0xB168BFA2
HIVE_CHAMBER_B_INTERNAL_ID = 0xE5F82542
HIVE_CHAMBER_C_INTERNAL_ID = 0x3AE18F4C
HIVE_SAVE_STATION_INTERNAL_ID = 0x298A46B7
HIVE_STORAGE_INTERNAL_ID = 0xBB04ED2C
HIVE_TRANSPORT_AREA_INTERNAL_ID = 0x847E2584
HIVE_TUNNEL_INTERNAL_ID = 0xBA47CB1F
INDUSTRIAL_SITE_INTERNAL_ID = 0xFBF7026A
ING_RELIQUARY_INTERNAL_ID = 0x4A3FAEBF
ING_WINDCHAMBER_INTERNAL_ID = 0x8FDF7C49
LAKE_ACCESS_INTERNAL_ID = 0x02C294BE
LANDING_SITE_INTERNAL_ID = 0x469F86A0
MEETING_GROUNDS_INTERNAL_ID = 0x263B762F
PATH_OF_EYES_INTERNAL_ID = 0xA1E4608C
PATH_OF_HONOR_INTERNAL_ID = 0xF202EB6D
PHAZON_GROUNDS_INTERNAL_ID = 0x7229A05E
PHAZON_PIT_INTERNAL_ID = 0xB65538F6
PLAIN_OF_DARK_WORSHIP_INTERNAL_ID = 0xF7602CF0
PORTAL_SITE_INTERNAL_ID = 0x140FDC57
PROFANE_PATH_INTERNAL_ID = 0xE90B6B28
RELIQUARY_ACCESS_INTERNAL_ID = 0x0044D8D8
RELIQUARY_GROUNDS_INTERNAL_ID = 0x4136D070
SACRED_BRIDGE_INTERNAL_ID = 0x8E76D210
SACRED_PATH_INTERNAL_ID = 0xC328BC32
SERVICE_ACCESS_INTERNAL_ID = 0x86FC1861
SHRINE_ACCESS_INTERNAL_ID = 0xB94091A2
SKY_TEMPLE_GATEWAY_INTERNAL_ID = 0x16828ED5
STORAGE_CAVERN_A_INTERNAL_ID = 0xB09B5078
STORAGE_CAVERN_B_INTERNAL_ID = 0xAF258380
TEMPLE_ASSEMBLY_SITE_INTERNAL_ID = 0x163904FE
TEMPLE_TRANSPORT_A_INTERNAL_ID = 0x14F3812B
TEMPLE_TRANSPORT_B_INTERNAL_ID = 0x1375C704
TEMPLE_TRANSPORT_C_INTERNAL_ID = 0x8B72A9DA
TORVUS_TRANSPORT_ACCESS_INTERNAL_ID = 0x678B3408
TRANSPORT_TO_AGON_WASTES_INTERNAL_ID = 0xFA35B470
TRANSPORT_TO_SANCTUARY_FORTRESS_INTERNAL_ID = 0x328E85F6
TRANSPORT_TO_TORVUS_BOG_INTERNAL_ID = 0x287DEF75
TROOPER_SECURITY_STATION_INTERNAL_ID = 0xF80A1CF9
WAR_RITUAL_GROUNDS_INTERNAL_ID = 0x4767E520
WINDCHAMBER_GATEWAY_INTERNAL_ID = 0x1C794B5A
WINDCHAMBER_TUNNEL_INTERNAL_ID = 0x6A0585B3
GAME_END_PART1_INTERNAL_ID = 0x752B2850
GAME_END_PART2_INTERNAL_ID = 0x9D221F4A
GAME_END_PART3_INTERNAL_ID = 0xC5250DBC
GAME_END_PART4_INTERNAL_ID = 0x9641773F
GAME_END_PART5_INTERNAL_ID = 0xCE4665C9

NAME_TO_ID_INTERNAL_ID = {
    "00_scandummy": 0x775664A5,
    "Abandoned Base": 0x89D924A7,
    "Accursed Lake": 0x012F9639,
    "Agon Transport Access": 0x650909ED,
    "Base Access": 0x07CE0C72,
    "Collapsed Tunnel": 0x1671BCCE,
    "Command Chamber": 0xCFB06832,
    "Communication Area": 0xDCEC348B,
    "Defiled Shrine": 0xB23C2110,
    "Dynamo Chamber": 0x600D7227,
    "Fortress Transport Access": 0xF080D688,
    "GFMC Compound": 0xEAA44A69,
    "Gateway Access": 0xBA85FBF7,
    "Grand Windchamber": 0xDD711FE2,
    "Hall of Eyes": 0x11F7FAE1,
    "Hall of Honored Dead": 0x1DA26BFF,
    "Hive Access Tunnel": 0x8CF4EFF5,
    "Hive Chamber A": 0xB168BFA2,
    "Hive Chamber B": 0xE5F82542,
    "Hive Chamber C": 0x3AE18F4C,
    "Hive Save Station": 0x298A46B7,
    "Hive Storage": 0xBB04ED2C,
    "Hive Transport Area": 0x847E2584,
    "Hive Tunnel": 0xBA47CB1F,
    "Industrial Site": 0xFBF7026A,
    "Ing Reliquary": 0x4A3FAEBF,
    "Ing Windchamber": 0x8FDF7C49,
    "Lake Access": 0x02C294BE,
    "Landing Site": 0x469F86A0,
    "Meeting Grounds": 0x263B762F,
    "Path of Eyes": 0xA1E4608C,
    "Path of Honor": 0xF202EB6D,
    "Phazon Grounds": 0x7229A05E,
    "Phazon Pit": 0xB65538F6,
    "Plain of Dark Worship": 0xF7602CF0,
    "Portal Site": 0x140FDC57,
    "Profane Path": 0xE90B6B28,
    "Reliquary Access": 0x0044D8D8,
    "Reliquary Grounds": 0x4136D070,
    "Sacred Bridge": 0x8E76D210,
    "Sacred Path": 0xC328BC32,
    "Service Access": 0x86FC1861,
    "Shrine Access": 0xB94091A2,
    "Sky Temple Gateway": 0x16828ED5,
    "Storage Cavern A": 0xB09B5078,
    "Storage Cavern B": 0xAF258380,
    "Temple Assembly Site": 0x163904FE,
    "Temple Transport A": 0x14F3812B,
    "Temple Transport B": 0x1375C704,
    "Temple Transport C": 0x8B72A9DA,
    "Torvus Transport Access": 0x678B3408,
    "Transport to Agon Wastes": 0xFA35B470,
    "Transport to Sanctuary Fortress": 0x328E85F6,
    "Transport to Torvus Bog": 0x287DEF75,
    "Trooper Security Station": 0xF80A1CF9,
    "War Ritual Grounds": 0x4767E520,
    "Windchamber Gateway": 0x1C794B5A,
    "Windchamber Tunnel": 0x6A0585B3,
    "game_end_part1": 0x752B2850,
    "game_end_part2": 0x9D221F4A,
    "game_end_part3": 0xC5250DBC,
    "game_end_part4": 0x9641773F,
    "game_end_part5": 0xCE4665C9,
}

DOCK_NAMES = {
    "00_scandummy": {
        "VirtualNorth": 0,
    },
    "Abandoned Base": {
        "East": 0,
        "North": 1,
        "South": 2,
        "VirtualNorth": 3,
    },
    "Accursed Lake": {
        "East": 0,
        "North": 1,
        "West": 2,
    },
    "Agon Transport Access": {
        "West": 0,
        "South": 1,
    },
    "Base Access": {
        "Docks_VirtualNorth": 0,
        "South": 1,
        "West": 2,
    },
    "Collapsed Tunnel": {
        "A__South": 0,
        "A__North1": 1,
    },
    "Command Chamber": {
        "West2": 0,
        "East": 1,
    },
    "Communication Area": {
        "South1": 0,
        "North": 1,
        "South11": 2,
    },
    "Defiled Shrine": {
        "North": 0,
        "East1": 1,
        "VirtualWest": 2,
    },
    "Dynamo Chamber": {
        "North": 0,
        "South": 1,
    },
    "Fortress Transport Access": {
        "West": 0,
        "South": 1,
    },
    "GFMC Compound": {
        "East": 0,
        "North": 1,
        "WestTop": 2,
        "West": 3,
    },
    "Gateway Access": {
        "West": 0,
        "WestUpper": 1,
        "NorthUpper": 2,
        "North": 3,
    },
    "Grand Windchamber": {
        "North": 0,
        "West": 1,
        "VirtualNorth1": 2,
    },
    "Hall of Eyes": {
        "Docks_VirtualNorth": 0,
        "South": 1,
        "West": 2,
    },
    "Hall of Honored Dead": {
        "South_Morphball": 0,
        "South": 1,
        "VirtualNorth": 2,
    },
    "Hive Access Tunnel": {
        "East": 0,
        "West": 1,
        "Floor": 2,
    },
    "Hive Chamber A": {
        "Ceiling": 0,
        "East": 1,
    },
    "Hive Chamber B": {
        "South": 0,
        "North": 1,
        "VirtualDock": 2,
    },
    "Hive Chamber C": {
        "blue_01_Temple_Hive_1_4_West_BigDoor": 0,
        "South": 1,
        "North1": 2,
    },
    "Hive Save Station": {
        "South": 0,
    },
    "Hive Storage": {
        "West": 0,
        "North1": 1,
    },
    "Hive Transport Area": {
        "East_Upper": 0,
        "group35_blue_01_Temple_Hive_1_4_East_BigDoor": 1,
        "West": 2,
    },
    "Hive Tunnel": {
        "West": 0,
        "East1": 1,
    },
    "Industrial Site": {
        "East": 0,
        "North": 1,
        "West": 2,
    },
    "Ing Reliquary": {
        "North_Top": 0,
    },
    "Ing Windchamber": {
        "North": 0,
        "West": 1,
        "VirtualNorth1": 2,
    },
    "Lake Access": {
        "A__South": 0,
        "A__North1": 1,
    },
    "Landing Site": {
        "North": 0,
        "East1": 1,
    },
    "Meeting Grounds": {
        "North": 0,
        "East1": 1,
        "EastTop": 2,
        "EastBottom": 3,
    },
    "Path of Eyes": {
        "East": 0,
        "North": 1,
        "South": 2,
        "VirtualNorth": 3,
    },
    "Path of Honor": {
        "West": 0,
        "WestUpper": 1,
        "NorthUpper": 2,
        "North": 3,
    },
    "Phazon Grounds": {
        "East": 0,
        "North": 1,
        "WestTop": 2,
        "West": 3,
    },
    "Phazon Pit": {
        "East": 0,
        "South": 1,
    },
    "Plain of Dark Worship": {
        "South": 0,
        "North": 1,
        "South1": 2,
        "VirtualNorth": 3,
    },
    "Portal Site": {
        "South": 0,
        "North": 1,
        "VirtualDock": 2,
    },
    "Profane Path": {
        "North": 0,
        "VirtualNorth1": 1,
    },
    "Reliquary Access": {
        "South": 0,
        "West": 1,
    },
    "Reliquary Grounds": {
        "South_Top": 0,
        "North": 1,
        "South_Bottom": 2,
    },
    "Sacred Bridge": {
        "East": 0,
        "South": 1,
    },
    "Sacred Path": {
        "South1": 0,
        "North": 1,
        "VirtualNorth1": 2,
    },
    "Service Access": {
        "South": 0,
        "East": 1,
        "West": 2,
        "East1": 3,
        "West11": 4,
    },
    "Shrine Access": {
        "South": 0,
        "East": 1,
        "West": 2,
        "East1": 3,
        "West11": 4,
    },
    "Sky Temple Gateway": {
        "South": 0,
        "VirtualNorth": 1,
        "Cinema_Dock": 2,
    },
    "Storage Cavern A": {
        "North_Top": 0,
    },
    "Storage Cavern B": {
        "North": 0,
    },
    "Temple Assembly Site": {
        "South": 0,
        "North": 1,
        "West": 2,
        "South1": 3,
        "VirtualNorth": 4,
    },
    "Temple Transport A": {
        "North": 0,
    },
    "Temple Transport B": {
        "East": 0,
    },
    "Temple Transport C": {
        "blue_0M_Temple_hall_West": 0,
    },
    "Torvus Transport Access": {
        "North": 0,
        "South": 1,
    },
    "Transport to Agon Wastes": {
        "Dock - North": 0,
    },
    "Transport to Sanctuary Fortress": {
        "East": 0,
    },
    "Transport to Torvus Bog": {
        "North": 0,
    },
    "Trooper Security Station": {
        "blue_0D_Temple_hall_South": 0,
        "blue_0D_Temple_hall_West": 1,
    },
    "War Ritual Grounds": {
        "North": 0,
        "EastTop": 1,
        "EastBottom": 2,
    },
    "Windchamber Gateway": {
        "East": 0,
        "South": 1,
    },
    "Windchamber Tunnel": {
        "South": 0,
        "East": 1,
    },
    "game_end_part1": {
        "South_Morphball": 0,
        "South": 1,
        "VirtualNorth": 2,
        "cinema_light2": 3,
        "cinema_light1": 4,
    },
    "game_end_part2": {
        "SouthLight1": 0,
        "VirtualNorth": 1,
        "North1": 2,
        "cinema_dock1": 3,
        "cinema_dock2": 4,
    },
    "game_end_part3": {
        "North": 0,
        "East1": 1,
        "cinema_dock": 2,
        "SPACEROOM": 3,
    },
    "game_end_part4": {
        "cinema_dock": 0,
        "North": 1,
    },
    "game_end_part5": {
        "cinema_dock": 0,
    },
}



import io
import typing
from concurrent.futures import ThreadPoolExecutor
from pathlib import Path

from ppc_asm.dol_file import DolEditor, DolHeader
from retro_data_structures.asset_manager import AssetManager, FileProvider
from retro_data_structures.base_resource import AssetId, BaseResource, NameOrAssetId, Resource
from retro_data_structures.crc import crc32
from retro_data_structures.formats.mlvl import Mlvl
from retro_data_structures.formats.mrea import Area
from retro_data_structures.formats.strg import Strg
from retro_data_structures.game_check import Game

T = typing.TypeVar("T")


class MemoryDol(DolEditor):
    def __init__(self, dol: bytes):
        super().__init__(DolHeader.from_bytes(dol))
        self.dol_file = io.BytesIO(dol)

    def _seek_and_read(self, seek: int, size: int):
        self.dol_file.seek(seek)
        return self.dol_file.read(size)

    def _seek_and_write(self, seek: int, data: bytes):
        self.dol_file.seek(seek)
        self.dol_file.write(data)


class PatcherEditor(AssetManager):
    memory_files: dict[NameOrAssetId, BaseResource]

    def __init__(self, provider: FileProvider, game: Game):
        super().__init__(provider, game)
        self.memory_files = {}

        if game in [Game.PRIME, Game.ECHOES]:
            self.dol = MemoryDol(provider.get_dol())
        else:
            self.dol = None

    def get_file(self, path: NameOrAssetId, type_hint: type[T] = BaseResource) -> T:
        if path not in self.memory_files:
            self.memory_files[path] = self.get_parsed_asset(path, type_hint=type_hint)
        return self.memory_files[path]

    def get_mlvl(self, name: NameOrAssetId) -> Mlvl:
        return self.get_file(name, Mlvl)

    def get_area(self, mlvl: NameOrAssetId, mrea: NameOrAssetId) -> Area:
        return self.get_mlvl(mlvl).get_area(mrea)

    def flush_modified_assets(self):
        with ThreadPoolExecutor() as executor:
            for name, resource in self.memory_files.items():
                executor.submit(self.replace_asset, name, resource)
        self.memory_files = {}

    def add_file(self,
                 name: str,
                 asset: Resource,
                 ) -> AssetId:
        asset_id = crc32(name)
        self.register_custom_asset_name(name, asset_id)
        self.add_new_asset(name, asset, ())
        return asset_id

    def duplicate_file(self, name: str, asset: AssetId) -> AssetId:
        return self.add_file(name, self.get_raw_asset(asset))

    def save_modifications(self, output_path: Path):
        super().save_modifications(output_path)

        if self.dol is not None:
            target_dol = output_path.joinpath("sys/main.dol")
            target_dol.parent.mkdir(exist_ok=True, parents=True)
            target_dol.write_bytes(self.dol.dol_file.getvalue())

    def add_or_replace_custom_asset(self, name: str, new_data: Resource) -> AssetId:
        if self.does_asset_exists(name):
            asset_id = self.replace_asset(name, new_data)
        else:
            asset_id = self.add_file(name, new_data)
        return asset_id

    def create_strg(self,
                    name: str,
                    strings: str | typing.Iterable[str] = (),
                    ) -> tuple[AssetId, Strg]:
        template_id = None
        if self.target_game == Game.ECHOES:
            # Strings/Worlds/TempleHub/01_Temple_LandingSite.STRG
            template_id = 0x2E681FEF

        if template_id is None:
            raise NotImplementedError()

        asset_id = self.duplicate_file(name, template_id)

        strg = self.get_file(asset_id, Strg)

        if isinstance(strings, str):
            strings = strings
        strings = list(strings)

        for lang in strg.languages:
            strg.set_strings(lang, strings)

        return asset_id, strg
